"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Cursor = void 0;
const PersistedSlice_1 = require("../slice/PersistedSlice");
class Cursor extends PersistedSlice_1.PersistedSlice {
    get anchorSide() {
        return this.type;
    }
    // ---------------------------------------------------------------- mutations
    set anchorSide(value) {
        this.update({ type: value });
    }
    anchor() {
        return this.anchorSide === 0 /* CursorAnchor.Start */ ? this.start : this.end;
    }
    focus() {
        return this.anchorSide === 0 /* CursorAnchor.Start */ ? this.end : this.start;
    }
    set(start, end = start, anchorSide = this.anchorSide) {
        this.start = start;
        this.end = end === start ? end.clone() : end;
        this.update({
            range: this,
            type: anchorSide,
        });
    }
    /**
     * Move one of the edges of the cursor to a new point.
     *
     * @param point Point to set the edge to.
     * @param endpoint 0 for "focus", 1 for "anchor."
     */
    setEndpoint(point, endpoint = 0) {
        if (this.start === this.end)
            this.end = this.end.clone();
        let anchor = this.anchor();
        let focus = this.focus();
        if (endpoint === 0)
            focus = point;
        else
            anchor = point;
        if (focus.cmpSpatial(anchor) < 0)
            this.set(focus, anchor, 1 /* CursorAnchor.End */);
        else
            this.set(anchor, focus, 0 /* CursorAnchor.Start */);
    }
    move(move) {
        const { start, end } = this;
        start.move(move);
        if (start !== end)
            end.move(move);
        this.set(start, end);
    }
    // ---------------------------------------------------------------- Printable
    toStringName() {
        const focusIcon = this.anchorSide === 0 /* CursorAnchor.Start */ ? '.→|' : '|←.';
        return `${super.toStringName()}, ${focusIcon}`;
    }
}
exports.Cursor = Cursor;
