import { Cursor } from './Cursor';
import { type ITimestampStruct } from '../../../json-crdt-patch/clock';
import { PersistedSlice } from '../slice/PersistedSlice';
import type { Range } from '../rga/Range';
import type { Peritext } from '../Peritext';
import type { Printable } from 'tree-dump/lib/types';
import type { Point } from '../rga/Point';
import type { SliceType } from '../slice/types';
import type { MarkerSlice } from '../slice/MarkerSlice';
import type { Slices } from '../slice/Slices';
/**
 * @todo Rename to `PeritextApi`.
 */
export declare class Editor implements Printable {
    readonly txt: Peritext;
    /**
     * Cursor is the the current user selection. It can be a caret or a
     * range. If range is collapsed to a single point, it is a caret.
     */
    readonly cursor: Cursor;
    constructor(txt: Peritext, slices: Slices);
    /** @deprecated */
    setCursor(start: number, length?: number): void;
    /** @deprecated */
    getCursorText(): string;
    /**
     * Ensures there is no range selection. If user has selected a range,
     * the contents is removed and the cursor is set at the start of the range as cursor.
     *
     * @todo If block boundaries are withing the range, remove the blocks.
     *
     * @returns Returns the cursor position after the operation.
     */
    collapseSelection(): ITimestampStruct;
    /**
     * Insert inline text at current cursor position. If cursor selects a range,
     * the range is removed and the text is inserted at the start of the range.
     */
    insert(text: string): void;
    /**
     * Deletes the previous character at current cursor position. If cursor
     * selects a range, deletes the whole range.
     */
    delete(): void;
    start(): Point | undefined;
    end(): Point | undefined;
    all(): Range | undefined;
    selectAll(): void;
    insStackSlice(type: SliceType, data?: unknown | ITimestampStruct): PersistedSlice;
    insOverwriteSlice(type: SliceType, data?: unknown | ITimestampStruct): PersistedSlice;
    insEraseSlice(type: SliceType, data?: unknown | ITimestampStruct): PersistedSlice;
    insMarker(type: SliceType, data?: unknown): MarkerSlice;
}
