import { PersistedSlice } from './PersistedSlice';
import { Range } from '../rga/Range';
import { SliceBehavior } from './constants';
import { MarkerSlice } from './MarkerSlice';
import type { Slice, SliceType } from './types';
import type { ITimestampStruct } from '../../../json-crdt-patch/clock';
import type { Stateful } from '../types';
import type { Printable } from 'tree-dump/lib/types';
import type { ArrChunk, ArrNode } from '../../../json-crdt/nodes';
import type { Model } from '../../../json-crdt/model';
import type { AbstractRga } from '../../../json-crdt/nodes/rga';
export declare class Slices implements Stateful, Printable {
    /** The model, which powers the CRDT nodes. */
    readonly model: Model<any>;
    /** The `arr` node, used as a set, where slices are stored. */
    readonly set: ArrNode;
    /** The text RGA. */
    protected readonly rga: AbstractRga<string>;
    private list;
    constructor(
    /** The model, which powers the CRDT nodes. */
    model: Model<any>, 
    /** The `arr` node, used as a set, where slices are stored. */
    set: ArrNode, 
    /** The text RGA. */
    rga: AbstractRga<string>);
    ins<S extends PersistedSlice<string>, K extends new (...args: ConstructorParameters<typeof PersistedSlice<string>>) => S>(range: Range, behavior: SliceBehavior, type: SliceType, data?: unknown, Klass?: K): S;
    insMarker(range: Range, type: SliceType, data?: unknown): MarkerSlice;
    insStack(range: Range, type: SliceType, data?: unknown): PersistedSlice;
    insOverwrite(range: Range, type: SliceType, data?: unknown): PersistedSlice;
    insErase(range: Range, type: SliceType, data?: unknown): PersistedSlice;
    protected unpack(chunk: ArrChunk): PersistedSlice;
    get(id: ITimestampStruct): PersistedSlice | undefined;
    del(id: ITimestampStruct): void;
    delSlices(slices: Slice[]): void;
    size(): number;
    forEach(callback: (item: Slice) => void): void;
    private _topologyHash;
    hash: number;
    refresh(): number;
    toString(tab?: string): string;
}
